@@ -1,6 +1,6 @@
 #!/bin/bash
 
-release=1.1
+release=1.3.1
 
 echo "********** Copying taglib -> taglib-$release..."
 
